==> ws-v3.70.8-src.tar.gz: ws-v3.70-8/include/WSDtimer.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDTIMER_H
#define WSDTIMER_H
#include <WScom.h>
#include <WSClistData.h>
#include <WSCroot.h>

typedef void (*WStimerProc)(WSCuchar,void*);

struct triggerProcRec{
  WStimerProc proc;
  WSCuchar rate;
  WSCuchar fclock;
  WSCbool  executed;
  void* data;
};

struct timerProcRec{
  WStimerProc proc;
  WSCuchar rate;
  WSCuchar fclock;
  void* data;
};

class WSDtimer :public WSCroot{

 protected:
  WSClistData  _cproc_list;
  WSClistData  _proc_list;
  WSCulong     _clock;

 public:
  WSDtimer();
  virtual ~WSDtimer();
  long addTriggerProc(WStimerProc,WSCuchar rate,void* ptr);
  long addTimerProc(WStimerProc,WSCuchar rate,void* ptr);
  void delTimerProc(long id);
  void delTriggerProc(long id);
  static void setCreateInstanceHandler( WSDtimer* (*hd)() );
  WSMFclassDef(WSDtimer,WSCroot);
};
extern WSDLEX WSDtimer* WSGIappTimer();
#endif

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSDtimer.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSDTIMER_H
#define WSDTIMER_H
#include <WScom.h>
#include <WSClistData.h>
#include <WSCroot.h>

typedef void (*WStimerProc)(WSCuchar,void*);

struct triggerProcRec{
  WStimerProc proc;
  WSCuchar rate;
  WSCuchar fclock;
  WSCbool  executed;
  void* data;
};

struct timerProcRec{
  WStimerProc proc;
  WSCuchar rate;
  WSCuchar fclock;
  void* data;
};

class WSDtimer :public WSCroot{

 protected:
  WSClistData  _cproc_list;
  WSClistData  _proc_list;
  WSCulong     _clock;

 public:
  WSDLEX32 WSDtimer();
  WSDLEX32 virtual ~WSDtimer();
  WSDLEX32 long addTriggerProc(WStimerProc,WSCuchar rate,void* ptr);
  WSDLEX32 long addTimerProc(WStimerProc,WSCuchar rate,void* ptr);
  WSDLEX32 void delTimerProc(long id);
  WSDLEX32 void delTriggerProc(long id);
  WSDLEX32 static void setCreateInstanceHandler( WSDtimer* (*hd)() );
  WSMFclassDef(WSDtimer,WSCroot);
};
extern WSDLEX WSDtimer* WSGIappTimer();
#endif
